summaryrefslogtreecommitdiffstats
path: root/src/gvcore/pngformattype.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-26 21:04:57 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-26 21:04:57 +0000
commitbf7f88413be3831a9372d323d02fc0335b9f9188 (patch)
tree516fdef9206245b40a14f99b4e3d9ef9289196e0 /src/gvcore/pngformattype.h
parente238aa77b1fb3c2f55aef2ef2c91ce52166d2cc8 (diff)
downloadgwenview-bf7f88413be3831a9372d323d02fc0335b9f9188.tar.gz
gwenview-bf7f88413be3831a9372d323d02fc0335b9f9188.zip
TQt4 port Gwenview
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/gwenview@1233720 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gvcore/pngformattype.h')
-rw-r--r--src/gvcore/pngformattype.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/gvcore/pngformattype.h b/src/gvcore/pngformattype.h
index 920ee0c..80d9c20 100644
--- a/src/gvcore/pngformattype.h
+++ b/src/gvcore/pngformattype.h
@@ -1,36 +1,36 @@
-// this code is copied from Qt, with code added to actually call consumer
+// this code is copied from TQt, with code added to actually call consumer
// methods that inform about the progress of loading
/****************************************************************************
**
**
** Implementation of PNG QImage IOHandler
**
** Created : 970521
**
** Copyright (C) 1992-2003 Trolltech AS. All rights reserved.
**
-** This file is part of the kernel module of the Qt GUI Toolkit.
+** This file is part of the kernel module of the TQt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** information about TQt Commercial License Agreements.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -41,7 +41,7 @@
#ifndef gvpngformattype_h
#define gvpngformattype_h
-#include <qasyncimageio.h>
+#include <tqasyncimageio.h>
namespace Gwenview {
@@ -50,9 +50,9 @@ namespace Gwenview {
*
* An incremental loader factory for PNG's.
*/
-class PNGFormatType : public QImageFormatType {
+class PNGFormatType : public TQImageFormatType {
public:
- QImageFormat* decoderFor(const uchar* buffer, int length);
+ TQImageFormat* decoderFor(const uchar* buffer, int length);
const char* formatName() const;
};
@@ -1,36 +1,36 @@
**
**
-** Implementation of PNG QImage IOHandler
+** Implementation of PNG TQImage IOHandler
**
** Created : 970521